summaryrefslogtreecommitdiffstats
path: root/src/kernel/qapplication_x11.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qapplication_x11.cpp')
-rw-r--r--src/kernel/qapplication_x11.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/kernel/qapplication_x11.cpp b/src/kernel/qapplication_x11.cpp
index e72bd63..8eecdb4 100644
--- a/src/kernel/qapplication_x11.cpp
+++ b/src/kernel/qapplication_x11.cpp
@@ -241,7 +241,7 @@ Q_EXPORT Atom qt_window_role = 0;
Q_EXPORT Atom qt_sm_client_id = 0;
Atom qt_xa_motif_wm_hints = 0;
Atom qt_cde_running = 0;
-Atom qt_kwin_running = 0;
+Atom qt_twin_running = 0;
Atom qt_kwm_running = 0;
Atom qt_gbackground_properties = 0;
Atom qt_x_incr = 0;
@@ -1980,7 +1980,7 @@ void qt_init_internal( int *argcptr, char **argv,
qt_x11_intern_atom( "_NET_WM_PING", &qt_net_wm_ping );
qt_x11_intern_atom( "_MOTIF_WM_HINTS", &qt_xa_motif_wm_hints );
qt_x11_intern_atom( "DTWM_IS_RUNNING", &qt_cde_running );
- qt_x11_intern_atom( "KWIN_RUNNING", &qt_kwin_running );
+ qt_x11_intern_atom( "KWIN_RUNNING", &qt_twin_running );
qt_x11_intern_atom( "KWM_RUNNING", &qt_kwm_running );
qt_x11_intern_atom( "GNOME_BACKGROUND_PROPERTIES", &qt_gbackground_properties );
@@ -2385,11 +2385,11 @@ void QApplication::x11_initialize_style()
unsigned long length, after;
uchar *data;
if ( !app_style &&
- XGetWindowProperty( appDpy, QPaintDevice::x11AppRootWindow(), qt_kwin_running,
+ XGetWindowProperty( appDpy, QPaintDevice::x11AppRootWindow(), qt_twin_running,
0, 1, False, AnyPropertyType, &type, &format, &length,
&after, &data ) == Success && length ) {
if ( data ) XFree( (char *)data );
// kwin is there. check if KDE's styles are available,
// otherwise use windows style
if ( (app_style = QStyleFactory::create("highcolor") ) == 0 )
app_style = QStyleFactory::create("windows");
@@ -2385,11 +2385,11 @@ void QApplication::x11_initialize_style()
&after, &data ) == Success && length ) {
if ( data ) XFree( (char *)data );
- // kwin is there. check if KDE's styles are available,
+ // twin is there. check if KDE's styles are available,
// otherwise use windows style
if ( (app_style = QStyleFactory::create("highcolor") ) == 0 )